﻿;==========================================================================================================================================================
; My personal constants
;==========================================================================================================================================================

#Author                         = "Miklos G Bolvary"                                                ; Author's name
#CopyRight                      = "MGB Technical Services 2014 "                                    ; Copyright holder
#Basename                       = "PasswordMuncher "                                                ; Base name for ini and dataabse
#Version                        = "v0.00b"                                                          ; Program version
#Program                        = #Basename + #Version                                              ; Copyright string
#Fish                           = "<°)))o><²³  "                                                    ; Beware the fish!!

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

UseSQLiteDatabase()                                                                                 ; 

;==========================================================================================================================================================
; Standard program data structure
;==========================================================================================================================================================

Structure ProgramData
  CurrentRecord.s                                                                                   ; 
  CurrentDirectory.s                                                                                ; Current working directory
  DatabaseName.s                                                                                    ; Local database name
  DatabaseHandle.i                                                                                  ; Opened database handle
  
  TitleColumn.i                                                                                     ; 
  FavouriteColumn.i                                                                                 ; 
  DeletedColumn.i                                                                                   ; 
  RecordColumn.i                                                                                    ; 
EndStructure

;==========================================================================================================================================================
; Appointment structure
;==========================================================================================================================================================

Structure PasswordData                                                                             ; 
  Title.s                                                                                           ; 
  Information.s                                                                                     ; 
  Favourite.s                                                                                       ; 
  Deleted.s                                                                                         ; 
  Record.s                                                                                          ; 
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Global constants, including structures
;==========================================================================================================================================================

Global Program.ProgramData                                                                         ; 
Global Password.PasswordData                                                                       ; Long form menu text as tooltips

;==========================================================================================================================================================
; Setup all directory variables
;==========================================================================================================================================================

Program\CurrentDirectory    = GetCurrentDirectory()                                                 ; Get working directories
Program\DatabaseName        = Program\CurrentDirectory + ReplaceString(#Basename, " ", "_") + #Version  +  ".sqlite" ; 

;============================================================================================================================================================
; 
;============================================================================================================================================================

Declare.s RepQuote(Instring.s)                                                                      ; Uncle Berikco's routine to properly replace single quotes with double for SQL passing
Declare   OpenSystemDatabase()                                                                      ; Try to open the system database and create missing tables
Declare.s DatabaseLastInsertRowId()

;============================================================================================================================================================
; Uncle Berikco's routine to properly replace single quotes with double for SQL passing
;============================================================================================================================================================

Procedure.s RepQuote(Instring.s)
  For i = 1 To Len(Instring.s)
    If Mid(Instring.s, i, 1) = "'"
      tmp.s = tmp.s + "''"
    Else
      tmp.s = tmp.s + Mid(Instring.s, i, 1)
    EndIf
  Next i
  ProcedureReturn tmp.s
EndProcedure

;==========================================================================================================================================================
; Try to open the system database and create missing tables
;==========================================================================================================================================================

Procedure OpenSystemDatabase()
  FileHandle.i = OpenFile(#PB_Any, Program\DatabaseName)
  If FileHandle.i
    CloseFile(FileHandle.i)
    Program\DatabaseHandle = OpenDatabase(#PB_Any, Program\DatabaseName, "", "")
    If Program\DatabaseHandle
      QueryString.s = "PRAGMA auto_vacuum = on"
      If Not DatabaseUpdate(Program\DatabaseHandle, QueryString.s)
        MessageRequester("Vacuum setup error", "Could not setup auto database vacuum.")
        ProcedureReturn
      EndIf
      QueryString.s = "CREATE TABLE IF NOT EXISTS Passwords("
      QueryString.s + "Title TEXT, Information TEXT, Favourite TEXT, Deleted TEXT, "
      QueryString.s + "Record INTEGER PRIMARY KEY AUTOINCREMENT)"
      If DatabaseUpdate(Program\DatabaseHandle, QueryString.s)
      EndIf
    Else
      MessageRequester("Database open error", "There was a serious problem attempting to connect to the system database. Could be corrupt or open by some other process. Exit Hive and try again.", #PB_MessageRequester_Ok)
      ProcedureReturn
    EndIf 
  Else
    MessageRequester("Database file open error", "Could not open or create raw database file.", #PB_MessageRequester_Ok)
    ProcedureReturn
  EndIf
EndProcedure

;============================================================================================================================================================
; Get the ID of the last inserted record
;============================================================================================================================================================

Procedure.s DatabaseLastInsertRowId()
  QueryString.s = "SELECT last_insert_rowid()"
  If DatabaseQuery(Program\DatabaseHandle, QueryString.s)
    If FirstDatabaseRow(Program\DatabaseHandle)
      RecordId.s = GetDatabaseString(Program\DatabaseHandle, 0)
    EndIf
    FinishDatabaseQuery(Program\DatabaseHandle)
  Else
    RecordId.s = ""
  EndIf
  ProcedureReturn RecordId.s
EndProcedure

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

OpenSystemDatabase()

ImportFileId.i = ReadFile(#PB_Any, Program\CurrentDirectory + "Pexport.txt")

If ImportFileId.i <> 0
  
  While Eof(ImportFileId.i) = 0
    
    ToCleanString.s = RepQuote(ReadString(ImportFileId.i))
    
    inTitle.s       = StringField(ToCleanString.s, 1, ",")
    inInformation.s = StringField(ToCleanString.s, 2, ",")
    inUsername.s    = StringField(ToCleanString.s, 3, ",")
    inPassword.s    = StringField(ToCleanString.s, 4, ",")
    
    Password\Title        = inTitle.s
    Password\Information  = inUsername.s + Chr(10) + Chr(13)  + inPassword.s + Chr(10) + Chr(13)  +  inInformation.s
    Password\Favourite    = "0"
    Password\Deleted      = "0"
    ; Password\Record       = RepQuote(GetGadgetText(#Gadget_Data_Recordnumber))
    
    With Password
      
      \Favourite  = "0"
      \Deleted    = "0"
      QueryString.s = "INSERT INTO Passwords("
      QueryString.s + "Title, Information, Favourite, Deleted) "
      QueryString.s + "VALUES("
      QueryString.s + "'"   +   \Title        + "'"
      QueryString.s + ", '" +   \Information  + "'"
      QueryString.s + ", '" +   \Favourite    + "'"
      QueryString.s + ", '" +   \Deleted      + "'"
      QueryString.s + ")"
      
      If DatabaseUpdate(Program\DatabaseHandle, QueryString.s)
        \Record = DatabaseLastInsertRowId()
        If \Record <> ""
          Debug "Imported:  " + \Title
        EndIf
      Else
        Debug DatabaseError()
      EndIf
      
    EndWith
    
  Wend
    
Else
  Debug "Could not open the input file"
EndIf
  
End

; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 15
; Folding = +
; EnableXP