﻿;==========================================================================================================================================================
; Add a new category to the database
;==========================================================================================================================================================

Procedure AddCategory()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if an existing window is opened
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> 1
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data form window
    ;----------------------------------------------------------------------------------------------
    
    If Window_Category()
      
      ;--------------------------------------------------------------------------------------------
      ; Window was opened so set mutex to prevent other windows from opening
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = 1
      
      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_PasswordMuncher, 1)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the hover gadgets to this window
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_Category_Save))
      
      AddHoverGadget(GadgetID(#Gadget_Category_Exit))
      
      ;--------------------------------------------------------------------------------------------
      ; Add the fast form close keyboard shortcut
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_Category, #PB_Shortcut_Escape,               #Shortcut_Category_Escape)
      
      AddKeyboardShortcut(#Window_Category, #PB_Shortcut_Alt | #PB_Shortcut_S, #Shortcut_Category_Save)
      
      AddKeyboardShortcut(#Window_Category, #PB_Shortcut_Alt | #PB_Shortcut_X, #Shortcut_Category_Exit)
      
      ;--------------------------------------------------------------------------------------------
      ; Setup the common add window message
      ;--------------------------------------------------------------------------------------------
      
      Message.s = "Add A New Category"
      
      ;--------------------------------------------------------------------------------------------
      ; Set the last window message for the closure routine later
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = Message.s
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the data window
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_Category, Message.s)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_Category_lCategory, "Add a new category above..")
      
      ;--------------------------------------------------------------------------------------------
      ; Get the last record number in the database and give the next probable record number
      ;--------------------------------------------------------------------------------------------
      
      NextRecord.i = Val(LastRecord("Record", "Categories")) + 1
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_Category_RecordNumber, "Record No: " + Str(NextRecord.i))
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the main window
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings", "Info", Message.s)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the data form window is topmost
      ;--------------------------------------------------------------------------------------------
      
      SetActiveWindow(#Window_Category)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the version field is selected
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_Category_Category)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings", "Error", "The program window could not be opened.")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Warn", "Another program window is still open, close that one first.")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 52
; FirstLine = 27
; Folding = -
; EnableXP
; HideErrorLog