﻿;==========================================================================================================================================================
; 
;==========================================================================================================================================================

Procedure AddNewData()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if a previous window is open
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> 1
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data window
    ;----------------------------------------------------------------------------------------------
    
    If Window_Data()
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetWindowCallback(@DataWindowCallback(), #Window_Data)

      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_PasswordMuncher, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; Warn other components a window is open and not to attempt to open another
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = 1
      
      ;--------------------------------------------------------------------------------------------
      ; Add the various keyboard shortcuts
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Escape, #Shortcut_Data_Escape)
      
      ;--------------------------------------------------------------------------------------------
      ; Add keyboard shortcuts as backup to the buttons, Good for people with sore mouse wrists
      ;--------------------------------------------------------------------------------------------
    
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_B,    #Shortcut_Data_Bold)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_U,    #Shortcut_Data_Underline)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_I,    #Shortcut_Data_Italic)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_S,    #Shortcut_Data_Strikeout)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_A,    #Shortcut_Data_Subscript)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_D,    #Shortcut_Data_Superscript)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_L,    #Shortcut_Data_Link)
    
      ;--------------------------------------------------------------------------------------------
      ; Make the selected font grow or shrink
      ;--------------------------------------------------------------------------------------------
    
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_Up,   #Shortcut_Data_FontUp)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Control | #PB_Shortcut_Down, #Shortcut_Data_FontDown)
      
      ;--------------------------------------------------------------------------------------------
      ; Fast exit from the program
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Alt     | #PB_Shortcut_S,   #Shortcut_Data_Save)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Alt     | #PB_Shortcut_I,   #Shortcut_Data_Import)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Alt     | #PB_Shortcut_E,   #Shortcut_Data_Export)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Alt     | #PB_Shortcut_L,   #Shortcut_Data_Search)
      
      AddKeyboardShortcut(#Window_Data, #PB_Shortcut_Alt     | #PB_Shortcut_X,   #Shortcut_Data_Exit)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the hover enabled images
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_Data_Save))
      
      AddHoverGadget(GadgetID(#Gadget_Data_Export))
      
      AddHoverGadget(GadgetID(#Gadget_Data_Import))
      
      AddHoverGadget(GadgetID(#Gadget_Data_Exit))
      
      ;--------------------------------------------------------------------------------------------
      ; Remove theme support from the comment box or it retains a border even when API removed
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTheme_(GadgetID(#Gadget_Data_Details),   @null.w, @null.w)
      
      ;--------------------------------------------------------------------------------------------
      ; Allow the editorgadget to send back event messages. Sparkie/Srod
      ;--------------------------------------------------------------------------------------------
      
      CurrentFlags.l = SendMessage_(GadgetID(#Gadget_Data_Details), #EM_GETEVENTMASK, 0, 0)
      
      SendMessage_(GadgetID(#Gadget_Data_Details), #EM_SETEVENTMASK, 0, #ENM_MOUSEEVENTS | #ENM_CHANGE | CurrentFlags) 
      
      ;--------------------------------------------------------------------------------------------
      ; FluidByte routine. Set ownerdrawn combo box's item height
      ;--------------------------------------------------------------------------------------------
      
      SendMessage_(GadgetID(#Gadget_Data_font), #CB_SETITEMHEIGHT, 0, 20)
      
      ;--------------------------------------------------------------------------------------------
      ; FluidByte routine. Find all the fonts in the system
      ;--------------------------------------------------------------------------------------------
      
      EnumFonts(#Gadget_Data_font)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Data_font, 0)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the standard font sizes to the size selector
      ;--------------------------------------------------------------------------------------------
      
      Restore BeginFontSizes
      
      While TempFontsizes.s <> "_EndFontSizes_"
        
        Read.s TempFontsizes.s
        
        If TempFontsizes.s <> "_EndFontSizes_"
          
          AddGadgetItem(#Gadget_Data_size, -1, TempFontsizes.s)
          
        EndIf
        
      Wend
      
      TempFontsize.s    = "<>"
      
      ;--------------------------------------------------------------------------------------------
      ; Make the first font in the list visible
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Data_size, 0)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the standard regional character sets to the selector (Not used yet)
      ;--------------------------------------------------------------------------------------------
      
      Restore BeginCharacterArea
      
      While TempCharacterArea.s <> "_EndCharacterArea_"
        
        Read.s TempCharacterArea.s
        
        If TempCharacterArea.s <> "_EndCharacterArea_"
          
          AddGadgetItem(#Gadget_Data_character, -1, TempCharacterArea.s)
          
        EndIf
        
      Wend
      
      TempFontsize.s    = "<>"
      
      ;--------------------------------------------------------------------------------------------
      ; Make the western character set the default visible one (not used yet)
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_Data_character, 8)
      
      ;--------------------------------------------------------------------------------------------
      ; Get the last record number in the database and give the next probable record number
      ;--------------------------------------------------------------------------------------------
      
      NextRecord.i = Val(LastRecord("Passwords", "Record")) + 1
      
      ;--------------------------------------------------------------------------------------------
      ; Set the common window and statusbar message
      ;--------------------------------------------------------------------------------------------
      
      Message.s = "Add New PasswordMuncher Item"
      
      ;--------------------------------------------------------------------------------------------
      ; Use the common message as a window identifier
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = Message.s
      
      ;--------------------------------------------------------------------------------------------
      ; Set the window title with the common message and next record number
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_Data, Message.s + "   --   Record number: " + Str(NextRecord.i) + " ?")
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      AddGadgetItem(#Gadget_Data_cCategory, -1, "", ImageID(#CategoryStandard))
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      QueryString.s = "SELECT * FROM Categories "
      
      QueryString.s + "ORDER BY Category"
      
      If DatabaseQuery(Program\DatabaseHandle,  QueryString.s)
        
        While NextDatabaseRow(Program\DatabaseHandle)
          
          passCategory.s  = KillQuote(GetDatabaseString(Program\DatabaseHandle, 0))
          
          AddGadgetItem(#Gadget_Data_cCategory, -1, passCategory.s, ImageID(#CategoryStandard))
          
        Wend
        
        FinishDatabaseQuery(Program\DatabaseHandle)
        
      EndIf
      
      SetGadgetState(#Gadget_Data_cCategory, 0)

      ;--------------------------------------------------------------------------------------------
      ; Set the current operation details on the the main window status bar
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_Data_Recordnumber,  Str(NextRecord.i) + " ?")
      
      ;--------------------------------------------------------------------------------------------
      ; Set the current operation details on the the main window status bar
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings",  "Info",  Message.s + "   --   Record number: " + Str(NextRecord.i) + " ?")
      
      ;--------------------------------------------------------------------------------------------
      ; Set focus on the appointment name field
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_Data_Title)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings",  "Error",  "Could not open the [" + Program\LastWindow + "] window.")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Warn",  "The [" +  Program\LastWindow + "] window is still open, close that one first.")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 78
; FirstLine = 75
; Folding = -
; EnableXP
; CompileSourceDirectory