﻿;==========================================================================================================================================================
; Need a unicode aware version of the API directory creator
;==========================================================================================================================================================

Import "shell32.lib"                                                                               ; Import 32 bit shell library
  SHCreateDirectory(*hwnd, pszPath.p-unicode)                                                       ; Grab the function that you want
EndImport                                                                                          ;

;==========================================================================================================================================================
; Use the SQLite database environment for data
;==========================================================================================================================================================

UseSQLiteDatabase()                                                                                 ; Tell compiler we are using SQLite support

;==========================================================================================================================================================
; Print related constants found by Siegfried Rings
;==========================================================================================================================================================

#READYSTATE_UNINITIALIZED       = 0                                                                 ; Print routine with WebGadget
#READYSTATE_LOADING             = 1                                                                 ; 
#READYSTATE_LOADED              = 2                                                                 ; 
#READYSTATE_INTERACTIVE         = 3                                                                 ; 
#READYSTATE_COMPLETE            = 4                                                                 ; 
#OLECMDID_PRINT                 = 6                                                                 ; 
#OLECMDID_PRINTPREVIEW          = 7                                                                 ; 
#OLECMDEXECOPT_DONTPROMPTUSER   = 2                                                                 ; 

;==========================================================================================================================================================
; Dealing with strikeout attributes on a font in a listicongadget
;==========================================================================================================================================================

#FontStrikeoutYes               = 0                                                                 ; 
#FontStrikeoutNo                = 1                                                                 ; 

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

#TitleBarClockTimer             = 624                                                               ; 

;==========================================================================================================================================================
; My personal constants
;==========================================================================================================================================================

#Author                         = "Miklos G Bolvary"                                                ; Author's name
#CopyRight                      = "MGB Technical Services 2014 "                                    ; Copyright holder
#Basename                       = "PasswordMuncher "                                                ; Base name for ini and dataabse
#Version                        = "v1.00b"                                                          ; Program version
#Program                        = #Basename + #Version                                              ; Copyright string
#Fish                           = "<°)))o><²³  "                                                    ; Beware the fish!!

;==========================================================================================================================================================
; Standard program data structure
;==========================================================================================================================================================

Structure ProgramData
  QuitValue.i                                                                                       ; Program quit value
  FirstTime.i                                                                                       ; Program first start
  WindowMutex.i                                                                                     ; 
  LastWindow.s                                                                                      ; 
  
  CurrentDate.s                                                                                     ; The current date minus the time component
  CurrentLine.i                                                                                     ; 
  CurrentRecord.s                                                                                   ; 
  
  CurrentDirectory.s                                                                                ; Current working directory
  DatabaseDirectory.s                                                                               ; Local database directory
  DatabaseName.s                                                                                    ; Local database name
  DatabaseHandle.i                                                                                  ; Opened database handle
  
  TemporaryDirectory.s                                                                              ; 
  
  SearchCueFont.i                                                                                   ; Searchbox cue font
  SearchNormalFont.i                                                                                ; Searchbox normal font
  SearchCueText.s                                                                                   ; Search box prompt text
  
  TitleColumn.i                                                                                     ; 
; InformationColumn.i                                                                               ; 
  CategoryColumn.i                                                                                  ; 
  FavouriteColumn.i                                                                                 ; 
  LockedColumn.i                                                                                    ; 
  DeletedColumn.i                                                                                   ; 
  RecordColumn.i                                                                                    ; 
  
  CategoryItemColumn.i                                                                              ; 
  CategoryRecordColumn.i                                                                            ; 
  
  OldCategoryString.s                                                                               ; 
  
  TrayState.i                                                                                       ; 
  
  LockState.i                                                                                       ; Is the program locked or not
  MD5FingerPrint.s                                                                                  ; The generated MD5 fingerprint of the password
  
  NewPassword.s                                                                                     ; 
  OldPassword.s                                                                                     ; 
  
  FontSize.i                                                                                        ; RTF testing stuff. Currently used font size
EndStructure

;==========================================================================================================================================================
; Password data  structure
;==========================================================================================================================================================

Structure PasswordData                                                                             ; 
  Title.s                                                                                           ; 0
  Information.s                                                                                     ; 
  Category.s                                                                                        ; 1
  Favourite.s                                                                                       ; 2
  Locked.s                                                                                          ; 3 
  Deleted.s                                                                                         ; 4
  Record.s                                                                                          ; 5
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Category structure
;==========================================================================================================================================================

Structure CategoryData                                                                             ; 
  Category.s                                                                                        ; 0
  Record.s                                                                                          ; 1
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Appointment list icon data
;==========================================================================================================================================================

Structure IconData
  HeaderListIcon.i                                                                                  ; 
  
  ListNormal.i                                                                                      ; 
  ListLocked.i                                                                                      ; 
  ListDeleted.i                                                                                     ; 
  ListFavourite.i                                                                                   ; 
EndStructure

;==========================================================================================================================================================
; Global constants, including structures
;==========================================================================================================================================================

Global Password.PasswordData                                                                       ; Long form menu text as tooltips
Global Category.CategoryData                                                                       ; 
Global Program.ProgramData                                                                         ; All my program variables
Global Icon.IconData                                                                               ; 

;==========================================================================================================================================================
; RTF testing stuff
;==========================================================================================================================================================

Global RTFLength.i, FontSize.i                                                                     ; 
Global NewList FaceName.s()                                                                       ; 
Global RtfFile.i                                                                                   ; 

Define *Buffer, i                                                                                  ; 

; Srod. Colour picker module. Define a color array. This is optional and consists of 12 elements, not all of which have to be defined.

Global Dim Colours(11)

; In this example we define 4 custom colors and mark the remaining 8 as undefined by setting them to -1.  (The user will not be able to select these undefined colours.)

  Colours(0) = #Green
  Colours(1) = #Blue
  Colours(2) = #Gray
  Colours(3) = #Red

For i = 4 To 11
  Colours(i) = -1
Next

lf.LOGFONT                                                                                          ; 
lf\lfCharset = #DEFAULT_CHARSET                                                                     ; 

;==========================================================================================================================================================
; NetMaestro's screen snap code
;==========================================================================================================================================================

Global ScreenW.i, ScreenH.i, SnapD.i = 50, AutoSnap.i = #True                                      ;

SystemParametersInfo_(#SPI_GETWORKAREA, 0, @wa.RECT, 0)                                             ; Client area of the desktop

ScreenW.i = wa\right                                                                                ;

screenH.i = wa\bottom                                                                               ;

;==========================================================================================================================================================
; Setup the search box cue fonts
;==========================================================================================================================================================

Program\SearchCueFont       = LoadFont(#PB_Any,   "Georgia",       13, #PB_Font_Italic)             ; Empty search cue font
Program\SearchNormalFont    = LoadFont(#PB_Any,   "Comic Sans MS", 13, 0)                           ; Filled cue box font
Program\SearchCueText       = Space(256)                                                            ; Set the cue text buffer

PokeS(@Program\SearchCueText, "Search string here...", -1, #PB_Unicode)                             ; Fill the buffer with the cue text

;==========================================================================================================================================================
; Dare and time testing, date display on title bar
;==========================================================================================================================================================

Program\CurrentDate         = FormatDate("%dd/%mm/%yyyy", Date())                                   ; Get the current system date without the time component

;==========================================================================================================================================================
; Setup all directory variables
;==========================================================================================================================================================

Program\CurrentDirectory    = GetCurrentDirectory()                                                 ; Get working directories
Program\DatabaseDirectory   = Program\CurrentDirectory + "Database\"                                ; Set working database directory
Program\TemporaryDirectory  = Program\CurrentDirectory + "Temporary\"                               ; Set temporary files directory

Program\DatabaseName        = Program\DatabaseDirectory + ReplaceString(#Basename, " ", "_") + #Version  +  ".sqlite" ; 

;==========================================================================================================================================================
; Create your program directories
;==========================================================================================================================================================

MakeSureDirectoryPathExists(Program\DatabaseDirectory)                                              ; Create the program's working directories if you can 
MakeSureDirectoryPathExists(Program\TemporaryDirectory)                                             ; Set temporary files directory

;==========================================================================================================================================================
; Initial program window quit state
;==========================================================================================================================================================

Program\QuitValue           =  0                                                                    ; Initial program quit value

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

Program\TitleColumn         = 0                                                                     ; 
;Program\Information        =                                                                       ; 
Program\CategoryColumn      = 1                                                                     ; 
Program\FavouriteColumn     = 2                                                                     ; 
Program\LockedColumn        = 3                                                                     ; 
Program\DeletedColumn       = 4                                                                     ; 
Program\RecordColumn        = 5                                                                     ; 

Program\CategoryItemColumn  = 0                                                                     ; 
Program\CategoryRecordColumn= 1                                                                     ; 

;==========================================================================================================================================================
; Keyboard shortcut text
;==========================================================================================================================================================

#Text_Category_Add          = "Add a new category"
#Text_Category_Copy         = "Copy selected category to clipboard"
#Text_Category_Delete       = "Delete selected category"
#Text_Category_Edit         = "Edit selected category"
#Text_Category_Save         = "Save edited category"
#Text_Category_Exit         = "Exit category form"
#Text_Category_Escape       = "Exit category form"

#Text_Add                   = "Add new password details"
#Text_Copy                  = "Copy password to clipboard"
#Text_Delete                = "Delete selected password"
#Text_Edit                  = "Edit selected password"
#Text_Favourite             = "Mark password as favourite"
#Text_Help                  = "Show " + #Program + " help"
#Text_Keyboard              = "Show " + #Program + " shortcuts"
#Text_Lock                  = "Lock the current password details"
#Text_Search                = "Search for password information"
#Text_Print                 = "Print password details"
#Text_Export                = "Export passwords to backup files (Text & XML)"
#Text_Vacuum                = "Permanently remove entries marked as deleted"
#Text_Exit                  = "Exit " + #Program

#Text_DataSave              = "Save new or edited password"
#Text_DataImport            = "Import from RTF text file"
#Text_DataExport            = "Export to RTF text file"
#Text_DataSearch            = "Search for a string in the editor"
#Text_DataExit              = "Exit the data editing window"
#Text_DataEscape            = "Exit the data editing window"

#Text_SearchFirst           = "Find first search string"
#Text_SearchEscape          = "Exit search window"

#Text_LockProgram           = "Lock " + #Program + " to the system tray"
#Text_EditPassword          = "Edit " + #Program + " password"
#Text_Enter                 = "Start searching for text string"

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

#Mess_Category_Add          = "Add a new category to the category list"
#Mess_Category_Copy         = "Copy the selected category to the system clipboard"
#Mess_Category_Delete       = "Delete the currently selected category"
#Mess_Category_Edit         = "Edit the currently selected category"
#Mess_Category_Save         = "Save the new or edited category"
#Mess_Category_Exit         = "Exit the category editing window"
#Mess_Category_Escape       = "Exit the category editing window"

#Mess_Add                   = "Add a new password and details to the database"
#Mess_Copy                  = "Copy the current password to the system clipboard"
#Mess_Delete                = "Delete the currently selected password and details"
#Mess_Edit                  = "Edit the currently selected password"
#Mess_Favourite             = "Mark the current pasword as a favourite of yours"
#Mess_Help                  = "Show " + #Program + " help pages if any"
#Mess_Keyboard              = "Show " + #Program + " keyboard shortcut keystrokes"
#Mess_Lock                  = "Lock the current password details against deletion"
#Mess_Search                = "Search for password information in the database"
#Mess_Print                 = "Print the currently selected password title and details"
#Mess_Export                = "Export all password details to backup files (Text & XML)"
#Mess_Vacuum                = "Permanently remove entries marked as deleted from the database"
#Mess_Exit                  = "Exit " + #Program + " immediately"

#Mess_SaveData              = "Save the newly added or edited data to the database"
#Mess_ImportData            = "Emport RTF text into the editor box"
#Mess_ExportData            = "Export the editor box data to an RTF file"
#Mess_SearchData              = "Find a string in the editor"
#Mess_ExitData              = "Exit the data editing window"
#Mess_EscapeData            = "Exit the data editing window"

#Mess_Search_SearchFirst    = "Find the first search string in editor window"
#Mess_Search_Escape         = "Exit the search window"

;==========================================================================================================================================================
; Alias the keys out to the routine that shows what the shortcut strings are and their explanations
;==========================================================================================================================================================

#ShortcutKeys_CategoryAdd      = #PB_Shortcut_Alt     | #PB_Shortcut_1
#ShortcutKeys_CategoryCopy     = #PB_Shortcut_Alt     | #PB_Shortcut_2
#ShortcutKeys_CategoryDelete   = #PB_Shortcut_Alt     | #PB_Shortcut_3
#ShortcutKeys_CategoryEdit     = #PB_Shortcut_Alt     | #PB_Shortcut_4
#ShortcutKeys_CategorySave     = #PB_Shortcut_Alt     | #PB_Shortcut_S
#ShortcutKeys_CategoryExit     = #PB_Shortcut_Alt     | #PB_Shortcut_X
#ShortcutKeys_CategoryEscape   = #PB_Shortcut_Escape

#ShortcutKeys_Add              = #PB_Shortcut_Alt     | #PB_Shortcut_A
#ShortcutKeys_Copy             = #PB_Shortcut_Alt     | #PB_Shortcut_C
#ShortcutKeys_Delete           = #PB_Shortcut_Alt     | #PB_Shortcut_D
#ShortcutKeys_Edit             = #PB_Shortcut_Alt     | #PB_Shortcut_E
#ShortcutKeys_Favourite        = #PB_Shortcut_Alt     | #PB_Shortcut_F
#ShortcutKeys_Help             = #PB_Shortcut_Alt     | #PB_Shortcut_H
#ShortcutKeys_Keyboard         = #PB_Shortcut_Alt     | #PB_Shortcut_K
#ShortcutKeys_Lock             = #PB_Shortcut_Alt     | #PB_Shortcut_L
#ShortcutKeys_Search           = #PB_Shortcut_Alt     | #PB_Shortcut_S
#ShortcutKeys_Help             = #PB_Shortcut_Alt     | #PB_Shortcut_H
#ShortcutKeys_Print            = #PB_Shortcut_Alt     | #PB_Shortcut_P
#ShortcutKeys_Export           = #PB_Shortcut_Alt     | #PB_Shortcut_X
#ShortcutKeys_Vacuum           = #PB_Shortcut_Alt     | #PB_Shortcut_V
#ShortcutKeys_Exit             = #PB_Shortcut_Alt     | #PB_Shortcut_Q

#ShortcutKeys_DataBold         = #PB_Shortcut_Control | #PB_Shortcut_B
#ShortcutKeys_DataUnderline    = #PB_Shortcut_Control | #PB_Shortcut_U
#ShortcutKeys_DataItalic       = #PB_Shortcut_Control | #PB_Shortcut_I
#ShortcutKeys_DataStrikeOut    = #PB_Shortcut_Control | #PB_Shortcut_S
#ShortcutKeys_DataSubscript    = #PB_Shortcut_Control | #PB_Shortcut_A
#ShortcutKeys_DataSuperscript  = #PB_Shortcut_Control | #PB_Shortcut_D
#ShortcutKeys_DataLink         = #PB_Shortcut_Control | #PB_Shortcut_L
#ShortcutKeys_DataFontUp       = #PB_Shortcut_Control | #PB_Shortcut_Up
#ShortcutKeys_DataFontDown     = #PB_Shortcut_Control | #PB_Shortcut_Down

#ShortcutKeys_DataSave         = #PB_Shortcut_Alt     | #PB_Shortcut_S
#ShortcutKeys_DataImport       = #PB_Shortcut_Alt     | #PB_Shortcut_I
#ShortcutKeys_DataExport       = #PB_Shortcut_Alt     | #PB_Shortcut_E
#ShortcutKeys_DataSearch       = #PB_Shortcut_Alt     | #PB_Shortcut_L
#ShortcutKeys_DataExit         = #PB_Shortcut_Alt     | #PB_Shortcut_X
#ShortcutKeys_DataEscape       = #PB_Shortcut_Escape

#ShortcutKeys_SearchFirst      = #PB_Shortcut_Return
#ShortcutKeys_SearchEscape     = #PB_Shortcut_Escape

#ShortcutKeys_LockProgram      = #PB_Shortcut_Control | #PB_Shortcut_L
#ShortcutKeys_EditPassword     = #PB_Shortcut_Control | #PB_Shortcut_E
#ShortcutKeys_Enter            = #PB_Shortcut_Return
 
;==========================================================================================================================================================
; Setup day and month literal names
;==========================================================================================================================================================

Global Dim NameOfDay.s(7)                                                                           ; Fill an array with the names of the days (Terry Hough I think)

   NameOfDay(0)      = "Sunday"
   NameOfDay(1)      = "Monday"
   NameOfDay(2)      = "Tuesday"
   NameOfDay(3)      = "Wednesday"
   NameOfDay(4)      = "Thursday"
   NameOfDay(5)      = "Friday"
   NameOfDay(6)      = "Saturday"

Global Dim DaysPerMonth(12)                                                                         ; Fill an array on how many days per month there are

  For X = 0 To 11     
    DaysPerMonth(X) = 31 
  Next

  DaysPerMonth(1)   = 28
  DaysPerMonth(3)   = 30
  DaysPerMonth(5)   = 30
  DaysPerMonth(8)   = 30
  DaysPerMonth(10)  = 30

Global Dim NameOfMonth.s(12)                                                                        ; Fill an array with the names of the months

  NameOfMonth(0)    = "January"
  NameOfMonth(1)    = "February"
  NameOfMonth(2)    = "March"
  NameOfMonth(3)    = "April"
  NameOfMonth(4)    = "May"
  NameOfMonth(5)    = "June"
  NameOfMonth(6)    = "July"
  NameOfMonth(7)    = "August"
  NameOfMonth(8)    = "September"
  NameOfMonth(9)    = "October"
  NameOfMonth(10)   = "November"
  NameOfMonth(11)   = "December"

Global Dim Years.s(19)                                                                              ; Fill an array with the years

  Years(0)          = "2002"
  Years(1)          = "2003"
  Years(2)          = "2004"
  Years(3)          = "2005"
  Years(4)          = "2006" 
  Years(5)          = "2007"
  Years(6)          = "2008"
  Years(7)          = "2009"
  Years(8)          = "2010"
  Years(9)          = "2011"
  Years(10)         = "2012"
  Years(11)         = "2013"
  Years(12)         = "2014"
  Years(13)         = "2015"
  Years(14)         = "2016"
  Years(15)         = "2017"
  Years(16)         = "2018"
  Years(17)         = "2019"
  Years(18)         = "2020"
  
;==========================================================================================================================================================
; Extra gadget constants
;==========================================================================================================================================================

Enumeration #GadgetIndex
  #Menu_PasswordMuncher                                                                             ; 
  #Menu_LockProgram                                                                                 ; 
  #Menu_EditPassword                                                                                ; 
  
  #ShortCut_StartUpPassword_Return                                                                  ; 
  #ShortCut_StartUpPassword_Escape                                                                  ; 

  #Shortcut_PasswordMuncher_EditPassword                                                            ; 
  #Shortcut_PasswordMuncher_LockProgram                                                             ; 
  
  #ShortCut_NewPassword_Return                                                                      ; 
  #ShortCut_NewPassword_Escape                                                                      ; 
  
  #ShortCut_EditPassword_Return                                                                     ; 
  #ShortCut_EditPassword_Escape                                                                     ; 
  
  #ShortCut_UnlockPassword_Return                                                                   ; 
  #ShortCut_UnlockPassword_Escape                                                                   ; 

  #Shortcut_Category_Add                                                                            ; 
  #Shortcut_Category_Copy                                                                           ; 
  #Shortcut_Category_Delete                                                                         ; 
  #Shortcut_Category_Edit                                                                           ; 
  #Shortcut_Category_Save                                                                           ; 
  #Shortcut_Category_Exit                                                                           ; 
  #Shortcut_Category_Escape                                                                         ; 
  
  #Shortcut_PasswordMuncher_Add                                                                     ; 
  #Shortcut_PasswordMuncher_Copy                                                                    ; 
  #Shortcut_PasswordMuncher_Delete                                                                  ; 
  #Shortcut_PasswordMuncher_Edit                                                                    ; 
  #Shortcut_PasswordMuncher_Favourite                                                               ; 
  #Shortcut_PasswordMuncher_Help                                                                    ; 
  #Shortcut_PasswordMuncher_Keyboard                                                                ; 
  #Shortcut_PasswordMuncher_Lock                                                                    ; 
  #Shortcut_PasswordMuncher_Search                                                                  ; 
  #Shortcut_PasswordMuncher_Print                                                                   ; 
  #Shortcut_PasswordMuncher_Export                                                                  ; 
  #Shortcut_PasswordMuncher_Vacuum                                                                  ; 
  #Shortcut_PasswordMuncher_Exit                                                                    ; 
  #Shortcut_PasswordMuncher_Enter                                                                   ; 
  
  #Shortcut_Data_Bold                                                                               ; 
  #Shortcut_Data_Underline                                                                          ; 
  #Shortcut_Data_Italic                                                                             ; 
  #Shortcut_Data_Strikeout                                                                          ; 
  #Shortcut_Data_Subscript                                                                          ; 
  #Shortcut_Data_Superscript                                                                        ; 
  #Shortcut_Data_Link                                                                               ; 
  #Shortcut_Data_FontUp                                                                             ; 
  #Shortcut_Data_FontDown                                                                           ; 
  #Shortcut_Data_Save                                                                               ; 
  #Shortcut_Data_Import                                                                             ; 
  #Shortcut_Data_Export                                                                             ; 
  #Shortcut_Data_Search                                                                             ; 
  #Shortcut_Data_Exit                                                                               ; 
  #Shortcut_Data_Escape                                                                             ; 
  
  #Shortcut_Search_SearchFirst                                                                      ; 
  #Shortcut_Search_Escape                                                                           ; 
  
  #Shortcut_Help_Escape                                                                             ; 
  #Shortcut_Keys_Escape                                                                             ; 
  
  #Systray_PasswordMuncher_Tray                                                                     ; 
EndEnumeration
  
;==========================================================================================================================================================
; Extra image constants
;==========================================================================================================================================================

Enumeration #ImageIndex                                                                            ; Follow on from visual designer created constants
  #ProgramIcon                                                                                      ; 
  
  #LockProgram                                                                                      ; 
  #EditPassword                                                                                     ; 

  #Shortcuts                                                                                        ; 
  
  #ListNormal                                                                                       ; 
  #ListLocked                                                                                       ; 
  #ListFavourite                                                                                    ; 
  #ListProtected                                                                                    ; 
  #ListDeleted                                                                                      ; 
  
  #CategoryEmpty                                                                                    ; 
  #CategoryStandard                                                                                 ; 
  
  #ComboLocked                                                                                      ; 
  #ComboUnlocked                                                                                    ; 
  #ComboAll                                                                                         ; 
  #ComboSql                                                                                         ; 
  
  #Image_AddCategory_P                                                                              ; 
  #Image_CopyCategory_P                                                                             ; 
  #Image_DeleteCategory_P                                                                           ; 
  #Image_EditCategory_P                                                                             ; 
      
  #Image_AddCategory_H                                                                              ; 
  #Image_CopyCategory_H                                                                             ; 
  #Image_DeleteCategory_H                                                                           ; 
  #Image_EditCategory_H                                                                             ; 
  
  #Image_Add_P                                                                                      ; 
  #Image_Copy_P                                                                                     ; 
  #Image_Delete_P                                                                                   ; 
  #Image_Edit_P                                                                                     ; 
  #Image_Favourite_P                                                                                ; 
  #Image_Lock_P                                                                                     ; 
  #Image_Search_P                                                                                   ; 
  #Image_Help_P                                                                                     ; 
  #Image_Print_P                                                                                    ; 
  #Image_Export_P                                                                                   ; 
  #Image_Vacuum_P                                                                                   ; 
  #Image_Exit_P
  
  #Image_Add_H                                                                                      ; 
  #Image_Copy_H                                                                                     ; 
  #Image_Delete_H                                                                                   ; 
  #Image_Edit_H                                                                                     ; 
  #Image_Favourite_H                                                                                ; 
  #Image_Lock_H                                                                                     ; 
  #Image_Search_H                                                                                   ; 
  #Image_Help_H                                                                                     ; 
  #Image_Print_H                                                                                    ; 
  #Image_Export_H                                                                                   ; 
  #Image_Vacuum_H                                                                                   ; 
  #Image_Exit_H                                                                                     ; 
  
  #Image_Data_Save_H                                                                                ; 
  #Image_Data_Export_H                                                                              ; 
  #Image_Data_Import_H                                                                              ; 
  #Image_Data_Exit_H                                                                                ; 
  
  #Image_Data_Save_P                                                                                ; 
  #Image_Data_Export_P                                                                              ; 
  #Image_Data_Import_P                                                                              ; 
  #Image_Data_Exit_P                                                                                ; 
  
  #Image_Category_Save_H                                                                            ; 
  #Image_Category_Exit_H                                                                            ; 
  
  #Image_Category_Save_P                                                                            ; 
  #Image_Category_Exit_P                                                                            ; 
EndEnumeration

;==========================================================================================================================================================
; Load images into memory from the datasection references
;==========================================================================================================================================================

CatchImage(#ProgramIcon,                        ?_ProgramIcon)                                      ; 

CatchImage(#LockProgram,                        ?_LockProgram)                                      ; 
CatchImage(#EditPassword,                       ?_EditPassword)                                     ; 
  
CatchImage(#Shortcuts,                          ?_Shortcuts)                                                ; 

CatchImage(#ListNormal,                         ?_ListNormal)                                               ; 
CatchImage(#ListLocked,                         ?_ListLocked)                                               ; 
CatchImage(#ListFavourite,                      ?_ListFavourite)                                            ; 
CatchImage(#ListProtected,                      ?_ListProtected)                                            ; 
CatchImage(#ListDeleted,                        ?_ListDeleted)                                              ; 

CatchImage(#CategoryEmpty,                      ?_CategoryEmpty)                                            ; 
CatchImage(#CategoryStandard,                   ?_CategoryStandard)                                         ; 

CatchImage(#ComboLocked,                        ?_ComboLocked)                                              ; 
CatchImage(#ComboUnlocked,                      ?_ComboUnlocked)                                            ; 
CatchImage(#ComboAll,                           ?_ComboAll)                                                 ; 
CatchImage(#ComboSql,                           ?_ComboSql)                                                 ; 
  
CatchImage(#Image_AddCategory_P,                ?_Image_AddCategory_P)                                      ; 
CatchImage(#Image_CopyCategory_P,               ?_Image_CopyCategory_P)                                     ; 
CatchImage(#Image_DeleteCategory_P,             ?_Image_DeleteCategory_P)                                   ; 
CatchImage(#Image_EditCategory_P,               ?_Image_EditCategory_P)                                     ; 
    
CatchImage(#Image_AddCategory_H,                ?_Image_AddCategory_H)                                      ; 
CatchImage(#Image_CopyCategory_H,               ?_Image_CopyCategory_H)                                     ; 
CatchImage(#Image_DeleteCategory_H,             ?_Image_DeleteCategory_H)                                   ; 
CatchImage(#Image_EditCategory_H,               ?_Image_EditCategory_H)                                     ; 
  
CatchImage(#Image_Add_P,                        ?_Image_Add_P)                                              ; 
CatchImage(#Image_Copy_P,                       ?_Image_Copy_P)                                             ; 
CatchImage(#Image_Delete_P,                     ?_Image_Delete_P)                                           ; 
CatchImage(#Image_Edit_P,                       ?_Image_Edit_P)                                             ; 
CatchImage(#Image_Favourite_P,                  ?_Image_Favourite_P)                                        ; 
CatchImage(#Image_Lock_P,                       ?_Image_Lock_P)                                             ; 
CatchImage(#Image_Search_P,                     ?_Image_Search_P)                                           ; 
CatchImage(#Image_Help_P,                       ?_Image_Help_P)                                             ; 
CatchImage(#Image_Print_P,                      ?_Image_Print_P)                                            ; 
CatchImage(#Image_Export_P,                     ?_Image_Export_P)                                           ; 
CatchImage(#Image_Vacuum_P,                     ?_Image_Vacuum_P)                                           ; 
CatchImage(#Image_Exit_P,                       ?_Image_Exit_P)                                             ; 

CatchImage(#Image_Add_H,                        ?_Image_Add_H)                                              ; 
CatchImage(#Image_Copy_H,                       ?_Image_Copy_H)                                             ; 
CatchImage(#Image_Delete_H,                     ?_Image_Delete_H)                                           ; 
CatchImage(#Image_Edit_H,                       ?_Image_Edit_H)                                             ; 
CatchImage(#Image_Favourite_H,                  ?_Image_Favourite_H)                                        ; 
CatchImage(#Image_Lock_H,                       ?_Image_Lock_H)                                             ; 
CatchImage(#Image_Search_H,                     ?_Image_Search_H)                                           ; 
CatchImage(#Image_Help_H,                       ?_Image_Help_H)                                             ; 
CatchImage(#Image_Print_H,                      ?_Image_Print_H)                                            ; 
CatchImage(#Image_Export_H,                     ?_Image_Export_H)                                           ; 
CatchImage(#Image_Vacuum_H,                     ?_Image_Vacuum_H)                                           ; 
CatchImage(#Image_Exit_H,                       ?_Image_Exit_H)                                             ; 

CatchImage(#Image_Data_Save_H,                  ?_Image_Data_Save_H)                                        ; 
CatchImage(#Image_Data_Export_H,                ?_Image_Data_Export_H)                                      ; 
CatchImage(#Image_Data_Import_H,                ?_Image_Data_Import_H)                                      ; 
CatchImage(#Image_Data_Exit_H,                  ?_Image_Data_Exit_H)                                        ; 

CatchImage(#Image_Data_Save_P,                  ?_Image_Data_Save_P)                                        ; 
CatchImage(#Image_Data_Export_P,                ?_Image_Data_Export_P)                                      ; 
CatchImage(#Image_Data_Import_P,                ?_Image_Data_Import_P)                                      ; 
CatchImage(#Image_Data_Exit_P,                  ?_Image_Data_Exit_P)                                        ; 

CatchImage(#Image_Category_Save_H,              ?_Image_Category_Save_H)                                    ; 
CatchImage(#Image_Category_Exit_H,              ?_Image_Category_Exit_H)                                    ; 

CatchImage(#Image_Category_Save_P,              ?_Image_Category_Save_P)                                    ; 
CatchImage(#Image_Category_Exit_P,              ?_Image_Category_Exit_P)                                    ; 

;==========================================================================================================================================================
; Datasection references
;==========================================================================================================================================================

DataSection
  ; Text files
  
; _About:                                   : IncludeBinary  "HelpFiles\About.rtf"                          ; 
  
  _Help:                                    : IncludeBinary  "HelpFiles\Help.rtf"                         ; 
  
  _ProgramIcon:                             : IncludeBinary  "Images\Passwords.png"                       ; 
  
  _LockProgram:                             : IncludeBinary  "Images\Others\MenuLock.ico"                 ; 
  _EditPassword:                            : IncludeBinary  "Images\Others\MenuEdit.ico"                 ; 
  
  _Shortcuts:                               : IncludeBinary  "Images\Shortcuts.ico"                       ; 
  
  _ListNormal:                              : IncludeBinary  "Images\List\Normal.ico"                     ; 
  _ListLocked:                              : IncludeBinary  "Images\List\Locked.ico"                     ; 
  _ListFavourite:                           : IncludeBinary  "Images\List\Favourite.ico"                  ; 
  _ListProtected:                           : IncludeBinary  "Images\List\Protected.ico"                  ; 
  _ListDeleted:                             : IncludeBinary  "Images\List\Deleted.ico"                    ; 
  
  _CategoryEmpty:                           : IncludeBinary  "Images\Category\Empty.ico"                  ; 
  _CategoryStandard:                        : IncludeBinary  "Images\Category\Standard.ico"               ; 
  
  _ComboLocked:                             : IncludeBinary  "Images\Others\Protected.ico"                ; 
  _ComboUnlocked:                           : IncludeBinary  "Images\Others\Unprotected.ico"              ; 
  _ComboAll:                                : IncludeBinary  "Images\Others\All.ico"                      ; 
  _ComboSql:                                : IncludeBinary  "Images\Others\Sql.ico"                      ; 

  _Image_AddCategory_P:                     : IncludeBinary  "Images\Categorylist\Add-p.png"              ; 
  _Image_CopyCategory_P:                    : IncludeBinary  "Images\Categorylist\Copy-p.png"             ; 
  _Image_DeleteCategory_P:                  : IncludeBinary  "Images\Categorylist\Delete-p.png"           ; 
  _Image_EditCategory_P:                    : IncludeBinary  "Images\Categorylist\Edit-p.png"             ; 
      
  _Image_AddCategory_H:                     : IncludeBinary  "Images\Categorylist\Add-p.png"              ; 
  _Image_CopyCategory_H:                    : IncludeBinary  "Images\Categorylist\Copy-p.png"             ; 
  _Image_DeleteCategory_H:                  : IncludeBinary  "Images\Categorylist\Delete-p.png"           ; 
  _Image_EditCategory_H:                    : IncludeBinary  "Images\Categorylist\Edit-p.png"             ; 

  _Image_Add_P:                             : IncludeBinary  "Images\Mainform\Add-p.png"                  ; 
  _Image_Copy_P:                            : IncludeBinary  "Images\Mainform\Copy-p.png"                 ; 
  _Image_Delete_P:                          : IncludeBinary  "Images\Mainform\Delete-p.png"               ; 
  _Image_Edit_P:                            : IncludeBinary  "Images\Mainform\Edit-p.png"                 ; 
  _Image_Favourite_P:                       : IncludeBinary  "Images\Mainform\Favourite-p.png"            ; 
  _Image_Lock_P:                            : IncludeBinary  "Images\Mainform\Lock-p.png"                 ; 
  _Image_Search_P:                          : IncludeBinary  "Images\Mainform\Search-p.png"               ; 
  _Image_Help_P:                            : IncludeBinary  "Images\Mainform\Help-p.png"                 ; 
  _Image_Print_P:                           : IncludeBinary  "Images\Mainform\Print-p.png"                ; 
  _Image_Export_P:                          : IncludeBinary  "Images\Mainform\Export-p.png"               ; 
  _Image_Vacuum_P:                          : IncludeBinary  "Images\Mainform\Vacuum-p.png"               ; 
  _Image_Exit_P:                            : IncludeBinary  "Images\Mainform\Exit-p.png"                 ; 
  
  _Image_Add_H:                             : IncludeBinary  "Images\Mainform\Add-h.png"                  ; 
  _Image_Copy_H:                            : IncludeBinary  "Images\Mainform\Copy-h.png"                 ; 
  _Image_Delete_H:                          : IncludeBinary  "Images\Mainform\Delete-h.png"               ; 
  _Image_Edit_H:                            : IncludeBinary  "Images\Mainform\Edit-h.png"                 ; 
  _Image_Favourite_H:                       : IncludeBinary  "Images\Mainform\Favourite-h.png"            ; 
  _Image_Lock_H:                            : IncludeBinary  "Images\Mainform\Lock-h.png"                 ; 
  _Image_Search_H:                          : IncludeBinary  "Images\Mainform\Search-h.png"               ; 
  _Image_Help_H:                            : IncludeBinary  "Images\Mainform\Help-h.png"                 ; 
  _Image_Print_H:                           : IncludeBinary  "Images\Mainform\Print-h.png"                ; 
  _Image_Export_H:                          : IncludeBinary  "Images\Mainform\Export-h.png"               ; 
  _Image_Vacuum_H:                          : IncludeBinary  "Images\Mainform\Vacuum-h.png"               ; 
  _Image_Exit_H:                            : IncludeBinary  "Images\Mainform\Exit-h.png"                 ; 
  
  _Image_Data_Save_H:                       : IncludeBinary  "Images\Mainform\Save-h.png"                 ; 
  _Image_Data_Export_H:                     : IncludeBinary  "Images\Mainform\Export-h.png"               ; 
  _Image_Data_Import_H:                     : IncludeBinary  "Images\Mainform\Import-h.png"               ; 
  _Image_Data_Exit_H:                       : IncludeBinary  "Images\Mainform\Exit-h.png"                 ; 

  _Image_Data_Save_P:                       : IncludeBinary  "Images\Mainform\Save-p.png"                 ; 
  _Image_Data_Export_P:                     : IncludeBinary  "Images\Mainform\Export-p.png"               ; 
  _Image_Data_Import_P:                     : IncludeBinary  "Images\Mainform\Import-p.png"               ; 
  _Image_Data_Exit_P:                       : IncludeBinary  "Images\Mainform\Exit-p.png"                 ; 
  
  _Image_Category_Save_H:                   : IncludeBinary  "Images\Categorylist\Save-h.png"             ; 
  _Image_Category_Exit_H:                   : IncludeBinary  "Images\Categorylist\Exit-h.png"             ; 
  
  _Image_Category_Save_P:                   : IncludeBinary  "Images\Categorylist\Save-p.png"             ; 
  _Image_Category_Exit_P:                   : IncludeBinary  "Images\Categorylist\Exit-p.png"             ; 
  
  BeginFontSizes:
  
  Data.s  "8"
  Data.s  "9"
  Data.s "10"
  Data.s "11"
  Data.s "12"
  Data.s "14"
  Data.s "16"
  Data.s "18"
  Data.s "20"
  Data.s "22"
  Data.s "24"
  Data.s "26"
  Data.s "28"
  Data.s "36"
  Data.s "48"
  Data.s "72"
  Data.s  "_EndFontSizes_"
  
  BeginCharacterArea:
    
  Data.s "Arabic"
  Data.s "Baltic"
  Data.s "Central European"
  Data.s "Cyrillic"
  Data.s "Greek"
  Data.s "Hebrew"
  Data.s "Turkish"
  Data.s "Vietnamese"
  Data.s "Western"
  Data.s  "_EndCharacterArea_"
EndDataSection

; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 774
; FirstLine = 737
; EnableXP
; UseIcon = Images\Serially.ico